(*
    ||M||  This file is part of HELM, an Hypertextual, Electronic        
    ||A||  Library of Mathematics, developed at the Computer Science     
    ||T||  Department, University of Bologna, Italy.                     
    ||I||                                                                
    ||T||  HELM is free software; you can redistribute it and/or         
    ||A||  modify it under the terms of the GNU General Public License   
    \   /  version 2 or (at your option) any later version.      
     \ /   This software is distributed as is, NO WARRANTY.     
      V_______________________________________________________________ *)

(* $Id: nCicPp.mli 9054 2008-10-13 15:51:11Z tassi $ *)

val ppterm: 
  context:NCic.context -> 
  subst:NCic.substitution -> 
  metasenv:NCic.metasenv ->
  ?inside_fix:bool ->
   NCic.term -> string

val ppcontext:
  ?sep:string ->
  subst:NCic.substitution -> 
  metasenv:NCic.metasenv ->
  NCic.context -> string 

val ppmetasenv:
  subst:NCic.substitution -> NCic.metasenv -> string

val ppsubst: metasenv:NCic.metasenv -> NCic.substitution -> string

val ppobj: NCic.obj -> string
